<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Selim Farsakoğlu <farsakogluselim@yahoo.de>
 * @author Aydın Coşkuner <aydinweb@gmail.com>
 * @author Cihan Kahveci <kahvecicihan@gmail.com>
 * @author Yavuz Selim <yavuzselim@gmail.com>
 * @author Caleb Maclennan <caleb@alerque.com>
 * @author farukerdemoncel@gmail.com
 * @author Mustafa Aslan <maslan@hotmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Sayfayı düzenle';
$lang['btn_source']            = 'Kaynağı göster';
$lang['btn_show']              = 'Sayfayı göster';
$lang['btn_create']            = 'Bu sayfayı oluştur';
$lang['btn_search']            = 'Ara';
$lang['btn_save']              = 'Kaydet';
$lang['btn_preview']           = 'Önizleme';
$lang['btn_top']               = 'Başa dön';
$lang['btn_newer']             = '<< daha yeniler';
$lang['btn_older']             = 'daha eskiler >>';
$lang['btn_revs']              = 'Eski sürümler';
$lang['btn_recent']            = 'En son değişiklikler';
$lang['btn_upload']            = 'Yükle';
$lang['btn_cancel']            = 'İptal';
$lang['btn_index']             = 'İndeks';
$lang['btn_secedit']           = 'Düzenle';
$lang['btn_login']             = 'Giriş yap';
$lang['btn_logout']            = 'Çıkış yap';
$lang['btn_admin']             = 'Yönetici';
$lang['btn_update']            = 'Güncelle';
$lang['btn_delete']            = 'Sil';
$lang['btn_back']              = 'Geri';
$lang['btn_backlink']          = 'Geri linkler';
$lang['btn_backtomedia']       = 'Çokluortam dosyası seçimine dön';
$lang['btn_subscribe']         = 'Sayfa Değişikliklerini Bildir';
$lang['btn_profile']           = 'Kullanıcı Bilgilerini Güncelle';
$lang['btn_reset']             = 'Sıfırla';
$lang['btn_resendpwd']         = 'Yeni şifre belirle';
$lang['btn_draft']             = 'Taslağı düzenle';
$lang['btn_recover']           = 'Taslağı geri yükle';
$lang['btn_draftdel']          = 'Taslağı sil';
$lang['btn_revert']            = 'Geri Yükle';
$lang['btn_register']          = 'Kayıt ol';
$lang['btn_apply']             = 'Uygula';
$lang['btn_media']             = 'Çokluortam Yöneticisi';
$lang['btn_deleteuser']        = 'Hesabımı Sil';
$lang['loggedinas']            = 'Giriş ismi';
$lang['user']                  = 'Kullanıcı ismi';
$lang['pass']                  = 'Parola';
$lang['newpass']               = 'Yeni Parola';
$lang['oldpass']               = 'Kullanılan parolayı doğrula';
$lang['passchk']               = 'Bir kez daha girin';
$lang['remember']              = 'Beni hatırla';
$lang['fullname']              = 'Tam isim';
$lang['email']                 = 'E-posta';
$lang['profile']               = 'Kullanıcı Bilgileri';
$lang['badlogin']              = 'Üzgünüz, Kullanıcı adı veya şifre yanlış oldu.';
$lang['badpassconfirm']        = 'Üzgünüz, parolanız yanlış';
$lang['minoredit']             = 'Küçük Değişiklikler';
$lang['draftdate']             = 'Taslak şu saatte otomatik kaydedildi:';
$lang['nosecedit']             = 'Sayfa yakın zamanda değiştirilmiştir, bölüm bilgisi eski kalmıştır. Bunun için bölüm yerine tüm sayfa yüklenmiştir.';
$lang['regmissing']            = 'Üzgünüz, tüm alanları doldurmalısınız.';
$lang['reguexists']            = 'Üzgünüz, bu isime sahip bir kullanıcı zaten mevcut.';
$lang['regsuccess']            = 'Kullanıcı oluşturuldu ve şifre e-posta adresine gönderildi.';
$lang['regsuccess2']           = 'Kullanıcı oluşturuldu.';
$lang['regmailfail']           = 'Şifrenizi e-posta ile gönderirken bir hata oluşmuş gibi görünüyor. Lütfen yönetici ile temasa geçiniz!';
$lang['regbadmail']            = 'Verilen e-posta adresi geçersiz gibi görünüyor - bunun bir hata olduğunu düşünüyorsanız yönetici ile temasa geçiniz.';
$lang['regbadpass']            = 'Girilen parolalar aynı değil. Lütfen tekrar deneyiniz.';
$lang['regpwmail']             = 'DokuWiki parolanız';
$lang['reghere']               = 'Daha hesabınız yok mu? Hemen bir tane açtırın!';
$lang['profna']                = 'Bu wiki kullanıcı bilgilerini değiştirmeyi desteklememektedir';
$lang['profnochange']          = 'Değişiklik yok, birşey yapılmadı.';
$lang['profnoempty']           = 'Boş isim veya e-posta adresine izin verilmiyor.';
$lang['profchanged']           = 'Kullanıcı bilgileri başarıyla değiştirildi.';
$lang['profnodelete']          = 'Bu wiki kullanıcı silmeyi desteklemiyor';
$lang['profdeleteuser']        = 'Hesabı Sil';
$lang['profdeleted']           = 'Bu wiki\'den hesabınız silindi';
$lang['profconfdelete']        = 'Bu wiki\'den hesabımı silmek istiyorum. <br/>Bu işlem geri alınamaz';
$lang['profconfdeletemissing'] = 'Onay kutusu işaretlenmedi';
$lang['pwdforget']             = 'Parolanızı mı unuttunuz? Yeni bir parola alın';
$lang['resendna']              = 'Bu wiki parolayı tekrar göndermeyi desteklememektedir.';
$lang['resendpwd']             = 'İçin yeni şifre belirle';
$lang['resendpwdmissing']      = 'Üzgünüz, tüm alanları doldurmalısınız.';
$lang['resendpwdnouser']       = 'Üzgünüz,  veritabanımızda bu kullanıcıyı bulamadık.';
$lang['resendpwdbadauth']      = 'Üzgünüz, bu doğrulama kodu doğru değil. Doğrulama linkini tam olarak kullandığınıza emin olun.';
$lang['resendpwdconfirm']      = 'Doğrulama linki e-posta adresinize gönderildi.';
$lang['resendpwdsuccess']      = 'Yeni parolanız e-posta adresinize gönderildi.';
$lang['license']               = 'Aksi belirtilmediği halde, bu wikinin içeriğinin telif hakları şu lisans ile korunmaktadır:';
$lang['licenseok']             = 'Not: Bu sayfayı değiştirerek yazınızın şu lisans ile yayınlanmasını kabul etmiş olacaksınız:';
$lang['searchmedia']           = 'Dosya Adı Ara:';
$lang['searchmedia_in']        = '%s içinde ara';
$lang['txt_upload']            = 'Yüklenecek dosyayı seç';
$lang['txt_filename']          = 'Dosya adı (zorunlu değil)';
$lang['txt_overwrt']           = 'Mevcut dosyanın üstüne yaz';
$lang['maxuploadsize']         = 'Yükleme dosya başına en fazla %s';
$lang['lockedby']              = 'Şu an şunun tarafından kilitli:';
$lang['lockexpire']            = 'Kilitin açılma tarihi:';
$lang['js']['willexpire']      = 'Bu sayfayı değiştirme kilidinin süresi yaklaşık bir dakika içinde geçecek.\nÇakışmaları önlemek için önizleme tuşunu kullanarak kilit sayacını sıfırla.';
$lang['js']['notsavedyet']     = 'Kaydedilmemiş değişiklikler kaybolacak.
Devam etmek istiyor musunuz?';
$lang['js']['searchmedia']     = 'Dosyalar için Ara';
$lang['js']['keepopen']        = 'Seçim yapıldığında bu pencereyi açık tut';
$lang['js']['hidedetails']     = 'Ayrıntıları gizle';
$lang['js']['mediatitle']      = 'Bağlantı Ayarları';
$lang['js']['mediadisplay']    = 'Bağlantı Tipi';
$lang['js']['mediaalign']      = 'Hizalama';
$lang['js']['mediasize']       = 'Resim büyüklüğü';
$lang['js']['mediatarget']     = 'Bağlantı hedefi';
$lang['js']['mediaclose']      = 'Kapat';
$lang['js']['mediainsert']     = 'Ekle';
$lang['js']['mediadisplayimg'] = 'Resmi görüntüle';
$lang['js']['mediadisplaylnk'] = 'Sadece bağlantıyı görüntüle ';
$lang['js']['mediasmall']      = 'Küçük versiyon';
$lang['js']['mediamedium']     = 'Orta versiyon';
$lang['js']['medialarge']      = 'Büyük versiyon';
$lang['js']['mediaoriginal']   = 'Orjinal versiyon';
$lang['js']['medialnk']        = 'Detay sayfasına bağlantı';
$lang['js']['mediadirect']     = 'Orjinal sayfaya bağlantı';
$lang['js']['medianolnk']      = 'Bağlantı yok';
$lang['js']['medianolink']     = 'Resme bağlantı verme';
$lang['js']['medialeft']       = 'Resmi sola hizala';
$lang['js']['mediaright']      = 'Resmi sağa hizala';
$lang['js']['mediacenter']     = 'Resmi ortaya hizala';
$lang['js']['medianoalign']    = 'Hizalama kullanma';
$lang['js']['nosmblinks']      = 'Windows paylaşımı sadece Microsoft Internet Explorer ile çalışmaktadır. Yine de hala bağlantıyı kopyalayıp yapıştırarak kullanabilirsiniz. ';
$lang['js']['linkwiz']         = 'Bağlantı sihirbazı';
$lang['js']['linkto']          = 'Bağlantı:';
$lang['js']['del_confirm']     = 'Bu girişi sil?';
$lang['js']['restore_confirm'] = 'Bu sürüme geri dönmek istediğinizden emin misiniz?';
$lang['js']['media_diff']      = 'Farkları gör:';
$lang['js']['media_diff_both'] = 'Yan yana';
$lang['js']['media_select']    = 'Dosyalar seç...';
$lang['js']['media_upload_btn'] = 'Yükle';
$lang['js']['media_done_btn']  = 'Bitti';
$lang['js']['media_drop']      = 'Yüklemek istediğiniz dosyaları buraya bırakın';
$lang['js']['media_cancel']    = 'kaldır';
$lang['js']['media_overwrt']   = 'Var olan dosyaların üzerine yaz';
$lang['rssfailed']             = 'Bu beslemeyi çekerken hata oluştu: ';
$lang['nothingfound']          = 'Hiçbir şey yok.';
$lang['mediaselect']           = 'Çokluortam dosyası seçimi';
$lang['fileupload']            = 'Çokluortam dosyası yükleme';
$lang['uploadsucc']            = 'Yükleme tamam';
$lang['uploadfail']            = 'Yükleme başarısız. Yetki hatası olabilir!';
$lang['uploadwrong']           = 'Yükleme engellendi. Bu dosya uzantısına izin verilmiyor!';
$lang['uploadexist']           = 'Dosya zaten var. Hiçbir şey yapılmadı.';
$lang['uploadbadcontent']      = 'Yüklenen içerik %s uzantısı ile uyuşmuyor.';
$lang['uploadspam']            = 'Yükleme işlemi spam karalistesi tarafından engellendi.';
$lang['uploadxss']             = 'Yükleme işlemi muhtemel kötü içerik sebebiyle engellendi.';
$lang['uploadsize']            = 'Yüklenmek istenen dosya boyutu çok büyük (en fazla %s)';
$lang['deletesucc']            = '"%s" dosyası silindi.';
$lang['deletefail']            = '"%s" silinemedi - yetkileri kontrol et.';
$lang['mediainuse']            = '"%s" dosyası silinmedi, hala kullanımda.';
$lang['namespaces']            = 'Namespaces';
$lang['mediafiles']            = 'Şuradaki kullanıma hazır dosyalar:';
$lang['accessdenied']          = 'Bu sayfayı görüntüleme yetkiniz bulunmamaktadır';
$lang['mediausage']            = 'Şu ';
$lang['mediaview']             = 'Özgün dosyayı göster';
$lang['mediaroot']             = 'Kök dizini';
$lang['mediaupload']           = 'Dosya bu namespace\'e yüklenir. Alt namespace oluşturmak için "Dosya adı" kısmınının başına alt namespace adını ekleyip ardından iki nokta koyun.';
$lang['mediaextchange']        = 'Dosya uzantısı .%s\'den .%s\'e çevrildi!';
$lang['reference']             = 'Şunun için referanslar:';
$lang['ref_inuse']             = 'Dosya silinemiyor, çünkü şu sayfalar tarafından hala kullanılmakta:';
$lang['ref_hidden']            = 'Bazı referanslar okuma yetkiniz olmayan sayfalarda';
$lang['hits']                  = 'tane bulundu';
$lang['quickhits']             = 'Uyan sayfalar';
$lang['toc']                   = 'İçindekiler';
$lang['current']               = 'mevcut';
$lang['yours']                 = 'Senin Sürümün';
$lang['diff']                  = 'Kullanılan sürüm ile farkları göster';
$lang['diff2']                 = 'Seçili sürümler arasındaki farkı göster';
$lang['difflink']              = 'Karşılaştırma görünümüne bağlantı';
$lang['line']                  = 'Satır';
$lang['breadcrumb']            = 'İz';
$lang['youarehere']            = 'Buradasınız';
$lang['lastmod']               = 'Son değiştirilme';
$lang['by']                    = 'Değiştiren:';
$lang['deleted']               = 'silindi';
$lang['created']               = 'oluşturuldu';
$lang['restored']              = 'eski sürüme dönüldü (%s)';
$lang['external_edit']         = 'Dışarıdan düzenle';
$lang['summary']               = 'Özeti düzenle';
$lang['noflash']               = 'Bu içeriği göstermek için <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Eklentisi</a> gerekmektedir.';
$lang['download']              = 'Parçacığı indir';
$lang['mail_newpage']          = 'sayfa eklenme:';
$lang['mail_changed']          = 'sayfa değiştirilme:';
$lang['mail_new_user']         = 'yeni kullanıcı';
$lang['mail_upload']           = 'dosya yüklendi:';
$lang['pages_changes']         = 'Sayfalar';
$lang['media_changes']         = 'Çokluortam dosyaları';
$lang['both_changes']          = 'Sayfalar ve çoklu ortam dosyaları';
$lang['qb_bold']               = 'Kalın Yazı';
$lang['qb_italic']             = 'Eğik Yazı';
$lang['qb_underl']             = 'Altı Çizgili Yazı';
$lang['qb_code']               = 'Kod Haline Getir';
$lang['qb_strike']             = 'Ortası Çizilmiş Yazı';
$lang['qb_h1']                 = '1. Seviye Başlık';
$lang['qb_h2']                 = '2. Seviye Başlık';
$lang['qb_h3']                 = '3. Seviye Başlık';
$lang['qb_h4']                 = '4. Seviye Başlık';
$lang['qb_h5']                 = '5. Seviye Başlık';
$lang['qb_h']                  = 'Başlık';
$lang['qb_hs']                 = 'Başlığı seç';
$lang['qb_hplus']              = 'Daha yüksek başlık';
$lang['qb_link']               = 'İç Bağlantı';
$lang['qb_extlink']            = 'Dış Bağlantı';
$lang['qb_hr']                 = 'Yatay Çizgi';
$lang['qb_ol']                 = 'Sıralı liste';
$lang['qb_ul']                 = 'Sırasız liste';
$lang['qb_media']              = 'Resim ve başka dosyalar ekle';
$lang['qb_sig']                = 'İmza Ekle';
$lang['qb_smileys']            = 'Gülen Yüzler';
$lang['qb_chars']              = 'Özel Karakterler';
$lang['admin_register']        = 'Yeni kullanıcı ekle...';
$lang['metaedit']              = 'Metaverileri Değiştir';
$lang['metasaveerr']           = 'Metaveri yazma başarısız ';
$lang['metasaveok']            = 'Metaveri kaydedildi';
$lang['img_backto']            = 'Şuna dön:';
$lang['img_title']             = 'Başlık';
$lang['img_caption']           = 'Serlevha';
$lang['img_date']              = 'Tarih';
$lang['img_fname']             = 'Dosya Adı';
$lang['img_fsize']             = 'Boyut';
$lang['img_artist']            = 'Fotoğrafçı';
$lang['img_copyr']             = 'Telif Hakkı';
$lang['img_format']            = 'Biçim';
$lang['img_camera']            = 'Fotoğraf Makinası';
$lang['img_keywords']          = 'Anahtar Sözcükler';
$lang['img_width']             = 'Genişlik';
$lang['img_height']            = 'Yükseklik';
$lang['img_manager']           = 'Ortam oynatıcısında göster';
$lang['subscr_m_subscribe']    = 'Kayıt ol';
$lang['subscr_m_receive']      = 'Al';
$lang['authtempfail']          = 'Kullanıcı doğrulama geçici olarak yapılamıyor. Eğer bu durum devam ederse lütfen Wiki yöneticine haber veriniz.';
$lang['authpwdexpire']         = 'Şifreniz %d gün sonra geçersiz hale gelecek, yakın bir zamanda değiştirmelisiniz.';
$lang['i_chooselang']          = 'Dili seçiniz';
$lang['i_installer']           = 'Dokuwiki Kurulum Sihirbazı';
$lang['i_wikiname']            = 'Wiki Adı';
$lang['i_enableacl']           = 'ACL\'yi etkinleştir (tavsiye edilir)';
$lang['i_superuser']           = 'Ana Kullanıcı';
$lang['i_problems']            = 'Kurulum sihirbazı aşağıda gösterilen sorunları buldu. Bunları düzeltmeden devam etmeniz mümkün değil.';
$lang['i_modified']            = 'Güzenlik sebebiyle bu script sadece yeni ve değiştirilmemiş bir Dokuwiki kurulumunda çalışır. Ya indirdiğiniz paketi yeniden açmalı ya da <a href="http://dokuwiki.org/install"> adresindeki Dokuwiki kurulum kılavuzu</a>na bakmalısınız.';
$lang['i_funcna']              = '<code>%s</code> PHP fonksiyonu bulunmamaktadır. Barındırma(Hosting) hizmetinde bu özellik kapatılmış olabilir.';
$lang['i_phpver']              = '<code>%s</code> PHP sürümü, gereken <code>%s</code>  sürümünden daha düşük. PHP kurulumunu yükseltmeniz gerekmektedir.';
$lang['i_permfail']            = '<code>%s</code> Dokuwiki tarafından yazılabilir değil. İzin ayarlarını bu klasör için düzeltmeniz gerekmektedir!';
$lang['i_confexists']          = '<code>%s</code> zaten var';
$lang['i_writeerr']            = '<code>%s</code> oluşturulamadı. Dosya/Klasör izin ayarlarını gözden geçirip dosyayı elle oluşturmalısınız.';
$lang['i_badhash']             = 'dokuwiki.php tanınamadı ya da değiştirilmiş (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - Yanlış veya boş değer';
$lang['i_success']             = 'Kurulum başarıyla tamamlandı. Şimdi install.php dosyasını silebilirsiniz. <a href="doku.php">Yeni DokuWikiniz</a>i kullanabilirsiniz.';
$lang['i_failure']             = 'Ayar dosyalarını yazarken bazı hatalar oluştu. <a href="doku.php">Yeni DokuWikiniz</a>i kullanmadan önce bu hatalarınızı elle düzeltmeniz gerekebilir.';
$lang['i_policy']              = 'İlk ACL ayarı';
$lang['i_pol0']                = 'Tamamen Açık Wiki (herkes okuyabilir, yazabilir ve dosya yükleyebilir)';
$lang['i_pol1']                = 'Açık Wiki (herkes okuyabilir, ancak  sadece üye olanlar yazabilir ve dosya yükleyebilir)';
$lang['i_pol2']                = 'Kapalı Wiki (sadece üye olanlar okuyabilir, yazabilir ve dosya yükleyebilir)';
$lang['i_retry']               = 'Tekrar Dene';
$lang['i_license']             = 'Lütfen içeriği hangi lisans altında yayınlamak istediğniizi belirtin:';
$lang['recent_global']         = '<b>%s</b> namespace\'i içerisinde yapılan değişiklikleri görüntülemektesiniz. Wiki\'deki tüm değişiklikleri de <a href="%s">bu adresten</a> görebilirsiniz. ';
$lang['years']                 = '%d yıl önce';
$lang['months']                = '%d ay önce';
$lang['weeks']                 = '%d hafta önce';
$lang['days']                  = '%d gün önce';
$lang['hours']                 = '%d saat önce';
$lang['minutes']               = '%d dakika önce';
$lang['seconds']               = '%d saniye önce';
$lang['wordblock']             = 'Değişikliğiniz kaydedilmedi çünkü istenmeyen mesaj içeriyor (spam).';
$lang['media_uploadtab']       = 'Karşıya yükle';
$lang['media_searchtab']       = 'Ara';
$lang['media_file']            = 'Dosya';
$lang['media_viewtab']         = 'Görünüm';
$lang['media_edittab']         = 'Düzenle';
$lang['media_historytab']      = 'Geçmiş';
$lang['media_list_thumbs']     = 'Küçük resimler';
$lang['media_list_rows']       = 'Satırlar';
$lang['media_sort_name']       = 'İsim';
$lang['media_sort_date']       = 'Tarih';
$lang['media_files']           = '%s deki dosyalar';
$lang['media_upload']          = '%s dizinine yükle';
$lang['media_search']          = '%s dizininde ara';
$lang['media_view']            = '%s';
$lang['media_edit']            = 'Düzenle %s';
$lang['media_history']         = 'Geçmiş %s';
$lang['media_perm_upload']     = 'Üzgünüm, karşıya dosya yükleme yetkiniz yok.';
$lang['media_restore']         = 'Bu sürümü eski haline getir';
